@@ -98,47 +98,46 @@ class TreeNode:
         self.children = []
 
     def evaluate(self):
-        try:
-            if self.token.ttype == TokenType.AND:
-                return self.children[0].evaluate() and self.children[1].evaluate()
-            elif self.token.ttype == TokenType.OR:
-                return self.children[0].evaluate() or self.children[1].evaluate()
-            elif self.token.ttype == TokenType.NOT:
-                return not self.children[0].evaluate()
-            elif self.token.ttype == TokenType.TRUE:
-                return True
-            elif self.token.ttype == TokenType.FALSE:
-                return False
-            elif self.token.ttype == TokenType.CONTAINS:
-                return self.children[1].evaluate() in self.children[0].evaluate()
-            elif self.token.ttype == TokenType.STARTSWITH:
-                return self.children[0].evaluate().startswith(self.children[1].evaluate())
-            elif self.token.ttype == TokenType.ENDSWITH:
-                return self.children[0].evaluate().endswith(self.children[1].evaluate())
-            elif self.token.ttype == TokenType.LOWER:
-                return self.children[0].evaluate().lower()
-            elif self.token.ttype == TokenType.UPPER:
-                return self.children[0].evaluate().upper()
-            elif self.token.ttype == TokenType.EQ:
-                return self.children[0].evaluate() == self.children[1].evaluate()
-            elif self.token.ttype == TokenType.NOTEQ:
-                return self.children[0].evaluate() != self.children[1].evaluate()
-            elif self.token.ttype == TokenType.LT:
-                return self.children[0].evaluate() < self.children[1].evaluate()
-            elif self.token.ttype == TokenType.LTEQ:
-                return self.children[0].evaluate() <= self.children[1].evaluate()
-            elif self.token.ttype == TokenType.GT:
-                return self.children[0].evaluate() > self.children[1].evaluate()
-            elif self.token.ttype == TokenType.GTEQ:
-                return self.children[0].evaluate() >= self.children[1].evaluate()
-            elif self.token.ttype == TokenType.NUMBER:
-                return self.numeric_value(self.token.ttext)
-            elif self.token.ttype == TokenType.STRING:
-                return self.token.ttext
-            elif self.token.ttype == TokenType.VARIABLE:
-                return TreeNode.var_dict[self.token.ttext]
-        except Exception as e:
-            raise ValueError(f"Error during parsing: {e}")
+        if self.token.ttype == TokenType.AND:
+            return self.children[0].evaluate() and self.children[1].evaluate()
+        elif self.token.ttype == TokenType.OR:
+            return self.children[0].evaluate() or self.children[1].evaluate()
+        elif self.token.ttype == TokenType.NOT:
+            return not self.children[0].evaluate()
+        elif self.token.ttype == TokenType.TRUE:
+            return True
+        elif self.token.ttype == TokenType.FALSE:
+            return False
+        elif self.token.ttype == TokenType.CONTAINS:
+            return self.children[1].evaluate() in self.children[0].evaluate()
+        elif self.token.ttype == TokenType.STARTSWITH:
+            return self.children[0].evaluate().startswith(self.children[1].evaluate())
+        elif self.token.ttype == TokenType.ENDSWITH:
+            return self.children[0].evaluate().endswith(self.children[1].evaluate())
+        elif self.token.ttype == TokenType.LOWER:
+            return self.children[0].evaluate().lower()
+        elif self.token.ttype == TokenType.UPPER:
+            return self.children[0].evaluate().upper()
+        elif self.token.ttype == TokenType.EQ:
+            return self.children[0].evaluate() == self.children[1].evaluate()
+        elif self.token.ttype == TokenType.NOTEQ:
+            return self.children[0].evaluate() != self.children[1].evaluate()
+        elif self.token.ttype == TokenType.LT:
+            return self.children[0].evaluate() < self.children[1].evaluate()
+        elif self.token.ttype == TokenType.LTEQ:
+            return self.children[0].evaluate() <= self.children[1].evaluate()
+        elif self.token.ttype == TokenType.GT:
+            return self.children[0].evaluate() > self.children[1].evaluate()
+        elif self.token.ttype == TokenType.GTEQ:
+            return self.children[0].evaluate() >= self.children[1].evaluate()
+        elif self.token.ttype == TokenType.NUMBER:
+            return self.numeric_value(self.token.ttext)
+        elif self.token.ttype == TokenType.STRING:
+            return self.token.ttext
+        elif self.token.ttype == TokenType.VARIABLE:
+            if self.token.ttext not in TreeNode.var_dict:
+                raise ValueError(f"Variable {self.token.ttext} not found in dictionary.")
+            return TreeNode.var_dict[self.token.ttext]
 
     # method to print the tree
     def traverse(self, level=0):
